import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { RekognitionClientResolvedConfig } from "../RekognitionClient";
/**
 * @internal
 */
export interface RekognitionHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface RekognitionHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<RekognitionClientResolvedConfig, HandlerExecutionContext, RekognitionHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultRekognitionHttpAuthSchemeParametersProvider: (config: RekognitionClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<RekognitionHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface RekognitionHttpAuthSchemeProvider extends HttpAuthSchemeProvider<RekognitionHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultRekognitionHttpAuthSchemeProvider: RekognitionHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: RekognitionHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: RekognitionHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
